<?php

/**
 * @wordpress-plugin
 * Plugin Name:       Easy Google Analytics
 * Plugin URI:        https://nicklarosa.net/wordpress-plugins/easy-google-analytics-wordpress-plugin/
 * Description:       A lightweight plugin for adding your google analytics tracking code to a wordpress installation written by Nick La Rosa
 * Version:           1.0.0
 * Author:            Nick La Rosa
 * Author URI:        https://nicklarosa.net
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       easy-google-analytics 
 */ 
/**
 * custom option and settings
 */
function easy_google_analytics_settings_init() {
 // register a new setting for "easy_google_analytics" page
	register_setting( 'easy_google_analytics', 'easy_google_analytics_options' );

 // register a new section in the "easy_google_analytics" page
	add_settings_section(
		'easy_google_analytics_section_developers',
		__( 'Easy Google Analytics.', 'easy_google_analytics' ),
		'easy_google_analytics_section_developers_cb',
		'easy_google_analytics'
	);

 // register a new field in the "easy_google_analytics_section_developers" section, inside the "easy_google_analytics" page
	add_settings_field(
		 'easy_google_analytics_field_tracking_code', // as of WP 4.6 this value is used only internally
		 // use $args' label_for to populate the id inside the callback
		 __( 'Tracking Code', 'easy_google_analytics' ),
		 'easy_google_analytics_field_tracking_code_cb',
		 'easy_google_analytics',
		 'easy_google_analytics_section_developers',
		 [
		 	'label_for' => 'easy_google_analytics_field_tracking_code',
		 	'class' => 'easy_google_analytics_row',
		 	'easy_google_analytics_custom_data' => 'custom',
		 ]
);
}

/**
 * register our easy_google_analytics_settings_init to the admin_init action hook
 */
add_action( 'admin_init', 'easy_google_analytics_settings_init' );

/**
 * custom option and settings:
 * callback functions
 */

// developers section cb

// section callbacks can accept an $args parameter, which is an array.
// $args have the following keys defined: title, id, callback.
// the values are defined at the add_settings_section() function.
function easy_google_analytics_section_developers_cb( $args ) {
	?>
	<p id="<?php echo esc_attr( $args['id'] ); ?>"><?php esc_html_e( 'Paste your tracking code.', 'easy_google_analytics' ); ?></p>
	<?php
}

// pill field cb

// field callbacks can accept an $args parameter, which is an array.
// $args is defined at the add_settings_field() function.
// wordpress has magic interaction with the following keys: label_for, class.
// the "label_for" key value is used for the "for" attribute of the <label>.
// the "class" key value is used for the "class" attribute of the <tr> containing the field.
// you can add custom key value pairs to be used inside your callbacks.
function easy_google_analytics_field_tracking_code_cb( $args ) {
 // get the value of the setting we've registered with register_setting()
	$options = get_option( 'easy_google_analytics_options' );
 // output the field

//esc_html_e( 'red pill', 'easy_google_analytics' );
	?>
	<textarea style='width:100%' rows=20 id="<?php echo esc_attr( $args['label_for'] ); ?>" data-custom="<?php echo esc_attr( $args['easy_google_analytics_custom_data'] ); ?>"
		name="easy_google_analytics_options[<?php echo esc_attr( $args['label_for'] ); ?>]"><?php echo $options[ $args['label_for']]; ?></textarea>


	<p class="description">
		<?php esc_html_e( 'The above code will be placed in your footer on every page of you site', 'easy_google_analytics' ); ?>
	</p>
	<p class="description">
		<?php esc_html_e( 'Not sure what your tracking code is? Try following these instructions to find them.', 'easy_google_analytics' ); ?><br>
		<a href="https://support.google.com/analytics/answer/1008080?hl=en" target="_new">Find your analytics tracking code</a>
	</p>
	<?php
}

/**
 * top level menu
 */
function easy_google_analytics_options_page() {
 // add top level menu page
	add_menu_page(
		'Easy Google Analytics',
		'Easy Google Analytics',
		'manage_options',
		'easy_google_analytics',
		'easy_google_analytics_options_page_html'
	);
}

/**
 * register our easy_google_analytics_options_page to the admin_menu action hook
 */
add_action( 'admin_menu', 'easy_google_analytics_options_page' );

/**
 * top level menu:
 * callback functions
 */
function easy_google_analytics_options_page_html() {
 // check user capabilities
	if ( ! current_user_can( 'manage_options' ) ) {
		return;
	}

 // add error/update messages

 // check if the user have submitted the settings
 // wordpress will add the "settings-updated" $_GET parameter to the url
	if ( isset( $_GET['settings-updated'] ) ) {
 // add settings saved message with the class of "updated"
		add_settings_error( 'easy_google_analytics_messages', 'easy_google_analytics_message', __( 'Tracking Code Saved', 'easy_google_analytics' ), 'updated' );
	}

 // show error/update messages
	settings_errors( 'easy_google_analytics_messages' );
	?>
	<div class="wrap">
		<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
		<form action="options.php" method="post">
			<?php
 // output security fields for the registered setting "easy_google_analytics"
			settings_fields( 'easy_google_analytics' );
 // output setting sections and their fields
 // (sections are registered for "easy_google_analytics", each field is registered to a specific section)
			do_settings_sections( 'easy_google_analytics' );
 // output save settings button
			submit_button( 'Save Settings' );
			?>
		</form>
	</div>
	<?php
}



add_action( 'wp_footer', 'display_easy_google_analytics', 10, 3 );

function display_easy_google_analytics(){
	$options = get_option( 'easy_google_analytics_options' );
	echo "<!-- Start Easy Google Analytics by Nick La Rosa -->";
	echo $options['easy_google_analytics_field_tracking_code'];
	echo "<!-- End Easy Google Analytics by Nick La Rosa -->";
}